pub(crate) async fn update_pruned_entry_id(
table_metadata_manager: &TableMetadataManagerRef,
topic: &str,
pruned_entry_id: EntryId,
) -> Result<()>Expand description
Updates the pruned entry id for the given topic.
pub(crate) async fn update_pruned_entry_id(
table_metadata_manager: &TableMetadataManagerRef,
topic: &str,
pruned_entry_id: EntryId,
) -> Result<()>Updates the pruned entry id for the given topic.